@@ -1,6 +1,6 @@
 package Authen::SASL::Perl::NTLM;
 # ABSTRACT: NTLM authentication plugin for Authen::SASL
-$Authen::SASL::Perl::NTLM::VERSION = '0.002';
+$Authen::SASL::Perl::NTLM::VERSION = '0.003';
 use 5.006;
 use strict;
 use warnings;
@@ -93,9 +93,13 @@ __END__
 
 Authen::SASL::Perl::NTLM - NTLM authentication plugin for Authen::SASL
 
+=for html
+<a href="https://travis-ci.org/stevenl/Authen-SASL-Perl-NTLM"><img src="https://travis-ci.org/stevenl/Authen-SASL-Perl-NTLM.svg?branch=master" alt="Build Status"></a>
+<a href='https://coveralls.io/r/stevenl/Authen-SASL-Perl-NTLM?branch=master'><img src='https://coveralls.io/repos/stevenl/Authen-SASL-Perl-NTLM/badge.png?branch=master' alt='Coverage Status' /></a>
+
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -166,7 +170,7 @@ Steven Lee <stevenwh.lee@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Lee.
+This software is copyright (c) 2016 by Steven Lee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
